summaryrefslogtreecommitdiff
path: root/TAO/tao/DiffServPolicy/DiffServPolicy_ORBInitializer.h
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/tao/DiffServPolicy/DiffServPolicy_ORBInitializer.h')
-rw-r--r--TAO/tao/DiffServPolicy/DiffServPolicy_ORBInitializer.h96
1 files changed, 10 insertions, 86 deletions
diff --git a/TAO/tao/DiffServPolicy/DiffServPolicy_ORBInitializer.h b/TAO/tao/DiffServPolicy/DiffServPolicy_ORBInitializer.h
index c2f04c46c04..f1825d8084e 100644
--- a/TAO/tao/DiffServPolicy/DiffServPolicy_ORBInitializer.h
+++ b/TAO/tao/DiffServPolicy/DiffServPolicy_ORBInitializer.h
@@ -2,31 +2,28 @@
//=============================================================================
/**
- * @file RT_ORBInitializer.h
+ * @file DiffServPolicy_ORBInitializer.h
*
* $Id$
*
- * @author Ossama Othman <ossama@uci.edu>
+ * @author Jaiganesh Balasubramanian <jai@dre.vanderbilt.edu>
+ * Johnny Willemsen <jwillemsen@remedy.nl>
*/
//=============================================================================
-#ifndef TAO_RT_ORB_INITIALIZER_H
-#define TAO_RT_ORB_INITIALIZER_H
+#ifndef TAO_DIFFSERV_POLICY_ORB_INITIALIZER_H
+#define TAO_DIFFSERV_POLICY_ORB_INITIALIZER_H
#include /**/ "ace/pre.h"
#include "tao/orbconf.h"
-
-#if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
-
-#include "tao/RTCORBA/rtcorba_export.h"
+#include "tao/DiffServPolicy/DiffServPolicy_Export.h"
#if !defined (ACE_LACKS_PRAGMA_ONCE)
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */
-
#include "tao/PI/PI.h"
#include "tao/LocalObject.h"
@@ -39,32 +36,12 @@
TAO_BEGIN_VERSIONED_NAMESPACE_DECL
-/// RTCORBA ORB initializer.
-class TAO_RT_ORBInitializer
+/// DiffServ Policy ORB initializer.
+class TAO_DiffServPolicy_Export TAO_DiffServPolicy_ORBInitializer
: public virtual PortableInterceptor::ORBInitializer
, public virtual TAO_Local_RefCounted_Object
{
public:
- /// Priority mapping types
- enum
- {
- TAO_PRIORITY_MAPPING_CONTINUOUS,
- TAO_PRIORITY_MAPPING_LINEAR,
- TAO_PRIORITY_MAPPING_DIRECT
- };
-
- enum
- {
- TAO_NETWORK_PRIORITY_MAPPING_LINEAR
- };
-
- TAO_RT_ORBInitializer (int priority_mapping_type,
- int network_priority_mapping_type,
- int ace_sched_policy,
- long sched_policy,
- long scope_policy,
- ACE_Time_Value const &dynamic_thread_idle_timeout);
-
virtual void pre_init (PortableInterceptor::ORBInitInfo_ptr info
ACE_ENV_ARG_DECL_WITH_DEFAULTS)
ACE_THROW_SPEC ((CORBA::SystemException));
@@ -75,61 +52,10 @@ public:
private:
/// Register RTCORBA policy factories.
void register_policy_factories (
PortableInterceptor::ORBInitInfo_ptr info
ACE_ENV_ARG_DECL);
-
-private:
- /// Instance of the RTCorba policy factory.
- /**
- * The RTCorba policy factory is stateless and reentrant, so share
- * a single instance between all ORBs.
- */
- PortableInterceptor::PolicyFactory_var policy_factory_;
-
- /// Priority mapping type.
- int const priority_mapping_type_;
-
- /// Network Priority mapping type.
- int const network_priority_mapping_type_;
-
- /// Scheduling policy.
- /**
- * Scheduling policy specified by the user through the
- * -ORBSchedPolicy option. This value is typically used by
- * functions like ACE_OS::thr_setprio() and
- * ACE_Sched_Params::priority_min(). Legal values are ACE_SCHED_RR,
- * ACE_SCHED_FIFO, and ACE_SCHED_OTHER.
- */
- int const ace_sched_policy_;
-
- /// Scheduling policy flag.
- /**
- * Scheduling policy specified by the user through the
- * -ORBSchedPolicy option. This value is typically used by ACE
- * thread creation functions. Legal values are THR_SCHED_RR,
- * THR_SCHED_FIFO, and THR_SCHED_DEFAULT.
- */
- long const sched_policy_;
-
- /// Scheduling scope flag.
- /**
- * Scheduling policy specified by the user through the
- * -ORBScopePolicy option. This value is typically used by ACE
- * thread creation functions. Legal values are THR_SCOPE_SYSTEM and
- * THR_SCOPE_PROCESS.
- */
- long const scope_policy_;
-
- /// Dynamic thread idle timeout
- /**
- * When using thread pool a certain number of dynamic threads can be created.
- * By default these threads are created when needed but never end, when this
- * timeout is specified the threads end themselves at the moment they
- * have not been serving any requests for the specified amount of time
- */
- ACE_Time_Value const dynamic_thread_idle_timeout_;
};
TAO_END_VERSIONED_NAMESPACE_DECL
@@ -138,8 +64,6 @@ TAO_END_VERSIONED_NAMESPACE_DECL
#pragma warning(pop)
#endif /* _MSC_VER */
-#endif /* TAO_HAS_CORBA_MESSAGING && TAO_HAS_CORBA_MESSAGING != 0 */
-
#include /**/ "ace/post.h"
-#endif /* TAO_RT_ORB_INITIALIZER_H */
+#endif /* TAO_DIFFSERV_POLICY_ORB_INITIALIZER_H */
@@ -75,61 +52,10 @@ public:
private:
- /// Register RTCORBA policy factories.
+ /// Register DiffServ policy factories.
void register_policy_factories (
PortableInterceptor::ORBInitInfo_ptr info